# Observabilité

## Journalisation

Journaux structurés avec prise en charge de l'échantillonnage et de la rédaction.

## Métriques

Exposez les compteurs et les distributions de latence (`p50/p95/p99`).

## Traçage

Utilisez la propagation du contexte de trace pour le suivi des demandes interservices.

## Santé

Utilisez les contrôles d’activité/préparation/démarrage pour les systèmes d’orchestration.